import java.io.IOException;
import java.io.PrintWriter;
import java.util.*;

public class Main {

    static class Point  {

        protected int x;
        protected int y;
        protected int id;

        public Point(int x, int y, int id) {
            this.x = x;
            this.y = y;
            this.id = id;
        }

        public double distance(Point otherPoint) {
            int diffX = x - otherPoint.x;
            int diffY = y - otherPoint.y;
            return Math.sqrt(1.0 * x * x + 1.0 * y + y);
        }
    }

    static class Bomb extends Point {

        protected int r;

        public Bomb(int x, int y, int id, int r) {
            super(x, y, id);
            this.r = r;
        }

        public double solveEquation(double x) {
            // move everything to origin (0, 0) firstly
            double newX = 1.0 * x - this.x;
            // (y - y0)^2 <= r^2 - x^2 --> y \in [-sqrt(r^2-x^2); sqrt(r^2-x^2)] plus Y-axis move
            return Math.sqrt(1.0 * r * r - 1.0 * newX * newX);
        }
    }

    static enum EventType {
        POINTS,
        BOMB_OPEN,
        BOMB_CLOSE
    }

    static class Event {

        private double time;
        private int itemId;
        private EventType eventType;

        public Event(double time, int itemId, EventType eventType) {
            this.time = time;
            this.itemId = itemId;
            this.eventType = eventType;
        }

    }

    private static final int MAX_X_VALUE = 10500;

    public static void main(String[] args) throws IOException {
        Scanner scanner = new Scanner(System.in);
        PrintWriter printWriter = new PrintWriter(System.out);
        int n = scanner.nextInt();
        ArrayList<Point>[] points = new ArrayList[MAX_X_VALUE];
        for (int i = 0; i < MAX_X_VALUE; ++i) {
            points[i] = new ArrayList<>();
        }
        for (int i = 0; i < n; ++i) {
            int x = scanner.nextInt(), y = scanner.nextInt();
            points[x].add(new Point(x, y, i));
        }
        ArrayList<Bomb> bombs = new ArrayList<>();
        ArrayList<Event> events = new ArrayList<>();
        int q = scanner.nextInt();
        for (int i = 0; i < q; ++i) {
            int x = scanner.nextInt(), y = scanner.nextInt(), r = scanner.nextInt();
            Bomb currentBomb = new Bomb(x, y, i, r);
            bombs.add(currentBomb);
            events.add(new Event(1.0 * x - 1.0 * r, currentBomb.id, EventType.BOMB_OPEN));
            events.add(new Event(1.0 * x + 1.0 * r, currentBomb.id, EventType.BOMB_CLOSE));
        }
        for (int x = 0; x < MAX_X_VALUE; ++x) {
            if (points[x].size() > 0) {
                events.add(new Event(1.0 * x, x, EventType.POINTS));
            }
        }
        Comparator<Event> eventComparator = (o1, o2) -> {
            if (o1 == o2) {
                return 0;
            }
            if (o1.time + 1e-7 < o2.time) {
                return -1;
            }
            if (o1.time - 1e-7 > o2.time) {
                return +1;
            }
            if (o1.eventType == o2.eventType) {
                return 0;
            }
            if (o1.eventType == EventType.BOMB_OPEN) {
                return -1;
            }
            if (o2.eventType == EventType.BOMB_OPEN) {
                return +1;
            }
            if (o1.eventType == EventType.POINTS) {
                return -1;
            }
            return 1;
        };
        int pointsCovered = 0;
        Collections.sort(events, eventComparator);
        Set<Integer> set = new HashSet<>();
        for (Event e: events) {
            if (e.eventType == EventType.BOMB_OPEN) {
                set.add(e.itemId);
            } else if (e.eventType == EventType.BOMB_CLOSE) {
                set.remove(e.itemId);
            } else if (e.eventType == EventType.POINTS) {
                if (set.size() == 0) {
                    continue;
                } else {
                    double currentX = e.time;
                    if (currentX == 2183.0) {
                        currentX = 2183.0;
                    }
                    ArrayList<Event> verticalLineEvents = new ArrayList<>();
                    for (Integer bomdId: set) {
                        Bomb bomb = bombs.get(bomdId);
                        if (1.0 * bomb.r * bomb.r - 1.0 * (currentX - bomb.x) * (currentX - bomb.x) < 0) {
                            continue;
                        }
                        double timeIn = bomb.y - bomb.solveEquation(currentX);
                        double timeOut = bomb.y + bomb.solveEquation(currentX);
                        verticalLineEvents.add(new Event(timeIn, -1, EventType.BOMB_OPEN));
                        verticalLineEvents.add(new Event(timeOut, -1, EventType.BOMB_CLOSE));
                    }
                    int currentIntX = e.itemId;
                    for (Point p: points[currentIntX]) {
                        verticalLineEvents.add(new Event(1.0 * p.y, -1, EventType.POINTS));
                    }
                    Collections.sort(verticalLineEvents, eventComparator);
                    int opennedBombs = 0;
                    for (Event vericalLineEvent: verticalLineEvents) {
                        if (vericalLineEvent.eventType == EventType.BOMB_OPEN) {
                            ++opennedBombs;
                        } else if (vericalLineEvent.eventType == EventType.BOMB_CLOSE) {
                            --opennedBombs;
                        } else if (vericalLineEvent.eventType == EventType.POINTS) {
                            if (opennedBombs > 0) {
                                ++pointsCovered;
                            }
                        }
                    }
                }
            }
        }
        int safePoints = n - pointsCovered;
        printWriter.println(safePoints);
        printWriter.close();
    }
}