#include <cstdio>
#include <iostream>
#include <cassert>
#include <vector>
#include <map>
#include <algorithm>
#include <sstream>
#include "testlib.h"

using namespace std;

const int MAXN = 1e5;
const int MAXX = 1e9;
int cur_test = -1;

string itoa(int x) 
{
    stringstream ss;
    string s;
    ss << x;
    ss >> s;
    return s;
}

int atoi(string s) 
{
    stringstream ss;
    int x;
    ss << s;
    ss >> x;
    return x;
}

void write_test(vector<int> a, int r) 
{
    startTest(cur_test++);
    cerr << cur_test << endl;
    printf("%d %d\n", (int)a.size(), r);
    for (int i = 0; i < (int)a.size(); i++)
        printf("%d%c", a[i], (i < (int)a.size() - 1) ? ' ' : '\n');
}

void gen_rand(int n, int r, int maxx)
{
    vector<int> a(n);
    for (int i = 0; i < n; i++)
        a[i] = rnd.next(-maxx, maxx);
    write_test(a, r);    
}

void gen_equal(int n, int r, int x)
{
    vector<int> a(n, x);
    write_test(a, r);    
}

void gen_intersect(int n, int r, int maxx)
{
    vector<int> a(n);
    int x = rnd.next(-maxx, maxx - r);
    for (int i = 0; i < n; i++)
        a[i] = x + rnd.next(r);
    write_test(a, r);    
}

void gen_special(int n, int r, int maxx)
{
    vector<int> a(n);
    int x = rnd.next(-maxx, maxx - 2 * r);
    int y = 2 * r - 1;
    for (int i = 0; i < n; i++)
        a[i] = x + y * rnd.next(2);
    write_test(a, r);    
}

void gen_special1(int n, int r)
{
    vector<int> a(n);
    int x = -MAXX;
    int y = 2 * r - 1;
    for (int i = 0; i < n; i++)
        a[i] = x + y * rnd.next(2);
    write_test(a, r);    
}

void gen_special2(int n, int r)
{
    vector<int> a(n);
    int x = MAXX;
    int y = 2 * r - 1;
    for (int i = 0; i < n; i++)
        a[i] = x - y * rnd.next(2);
    write_test(a, r);    
}



int main(int argc, char * argv[]) 
{
    registerGen(argc, argv, 1);
    cur_test = atoi(argv[1]);
    gen_rand(1, 100, 10);
    gen_rand(10, 2, 5);
    gen_equal(15, 4, 7);
    gen_intersect(7, 3, 10);
    gen_special(10, 3, 10);
    for (int i = 100, j = 1000; i <= MAXN; i *= 10, j *= 10) {
        gen_rand(rnd.next(i/2, i), rnd.next(j), j);
        gen_equal(rnd.next(i/2, i), rnd.next(j), j);
        gen_intersect(rnd.next(i/2, i), rnd.next(j), j);
        gen_special(rnd.next(i/2, i), rnd.next(j), j);
    }
    gen_rand(MAXN, MAXX, 10);
    gen_special1(5, 1);
    gen_special2(6, 2);
    gen_equal(MAXN, 1, MAXX);
    gen_equal(MAXN, 1, -MAXX);
    gen_equal(MAXN, 10, MAXX);
    gen_equal(MAXN, 13, -MAXX);
    gen_equal(MAXN, MAXX, MAXX);
    gen_equal(MAXN, MAXX, -MAXX);
    gen_rand(MAXN, MAXX, MAXX);
    gen_intersect(MAXN, MAXX, MAXX);
    gen_special(MAXN, MAXX, MAXX);
    gen_special1(MAXN, 7);
    gen_special2(MAXN, 3);
    gen_special1(MAXN, MAXX);
    gen_special2(MAXN, MAXX);
    return 0;
}